@@ -15,9 +15,6 @@
 # You should have received a copy of the GNU General Public License
 # along with icd. If not, see <http:#www.gnu.org/licenses/>.
 
-utils::globalVariables(c("icd9_majors", "icd9_chapters",
-                         "icd9_sub_chapters", "icd10cm2016"))
-
 #' Explain ICD-9 and ICD-10 codes in English
 #'
 #' Convert 'decimal' format (123.45 style) ICD-9 codes into the name and
@@ -30,8 +27,8 @@ utils::globalVariables(c("icd9_majors", "icd9_chapters",
 #'   which exactly encompass certain subsets. E.g. If all cholera diagnoses are
 #'   provided, only '001 - Cholera' needs to be displayed, not all sub-types.
 #' @param brief single logical value, default is \code{FALSE}. If \code{TRUE},
-#'   the short description from the canonical CMS descriptions (included in
-#'   \code{data-raw}) will be used, otherwise the long description is used.
+#'   the short description from the canonical CMS descriptions will be used,
+#'   otherwise the long description is used.
 #' @param warn single logical value, default is \code{TRUE}, meaning that codes
 #'   which do not correspond to diagnoses, or to three-digit codes, will trigger
 #'   a warning.
@@ -56,7 +53,9 @@ explain <- function(...)
   UseMethod("explain")
 
 #' @rdname explain
-#' @details \code{explain_icd} is a synonym for \code{\link{explain}} to avoid conflict with \code{dplyr::explain}. Alternative is to use \code{icd::explain}.
+#' @details \code{explain_icd} is a synonym for \code{\link{explain}} to avoid
+#'   conflict with \code{dplyr::explain}. Alternative is to use
+#'   \code{icd::explain}.
 #' @keywords internal
 explain_icd <- function(...) explain(...)
 
@@ -108,7 +107,7 @@ explain.icd9cm <- function(x, short_code = guess_short(x),
   }
   mj <- unique(get_major.icd9(x, short_code = TRUE))
 
-  mjexplain <- names(icd9_majors)[icd9_majors %in% mj[mj %in% x]]
+  mjexplain <- names(icd::icd9_majors)[icd::icd9_majors %in% mj[mj %in% x]]
   # don't double count when major is also billable
   x <- x[x %nin% mj]
   desc_field <- ifelse(brief, "short_desc", "long_desc")
@@ -138,7 +137,7 @@ explain.icd10cm <- function(x, short_code = guess_short(x),
     x <- decimal_to_short.icd10(x)
 
   # this is a linear lookup, but usually only "explaining" one or a few codes at a time.
-  icd10cm2016[icd10cm2016[["code"]] %in% unique(as_char_no_warn(x)),
+  icd::icd10cm2016[icd::icd10cm2016[["code"]] %in% unique(as_char_no_warn(x)),
               ifelse(brief, "short_desc", "long_desc")]
 }
 
@@ -174,19 +173,19 @@ icd9_get_chapters <- function(x, short_code = guess_short(x), verbose = FALSE) {
 
   # could consider faster factor generation
   out <- data.frame(
-    three_digit = factor(rep(NA, lenm), levels = c(icd9_majors, NA)),
-    major = factor(rep(NA, lenm), levels = c(names(icd9_majors), NA)),
-    sub_chapter = factor(rep(NA, lenm), levels = c(names(icd9_sub_chapters), NA)),
-    chapter = factor(rep(NA, lenm), levels = c(names(icd9_chapters), NA))
+    three_digit = factor(rep(NA, lenm), levels = c(icd::icd9_majors, NA)),
+    major = factor(rep(NA, lenm), levels = c(names(icd::icd9_majors), NA)),
+    sub_chapter = factor(rep(NA, lenm), levels = c(names(icd::icd9_sub_chapters), NA)),
+    chapter = factor(rep(NA, lenm), levels = c(names(icd::icd9_chapters), NA))
   )
 
-  chap_lookup <- lapply(icd9_chapters, function(y)
+  chap_lookup <- lapply(icd::icd9_chapters, function(y)
     vec_to_env_true(
       expand_range_major.icd9(y[["start"]], y[["end"]], defined = FALSE)
     )
   )
 
-  subchap_lookup <- lapply(icd9_sub_chapters, function(y)
+  subchap_lookup <- lapply(icd::icd9_sub_chapters, function(y)
     vec_to_env_true(
       expand_range_major.icd9(y[["start"]], y[["end"]], defined = FALSE)
     )
@@ -195,23 +194,24 @@ icd9_get_chapters <- function(x, short_code = guess_short(x), verbose = FALSE) {
   for (i in 1L:length(majors)) {
     if (verbose)
       message("icd9_get_chapters: working on major ", majors[i], ", row ", i)
-    for (chap_num in 1L:length(icd9_chapters)) {
+    for (chap_num in 1L:length(icd::icd9_chapters)) {
       if (majors[i] %ine% chap_lookup[[chap_num]]) {
-        out[i, "chapter"] <- names(icd9_chapters)[chap_num]
+        out[i, "chapter"] <- names(icd::icd9_chapters)[chap_num]
         break
       }
     }
-    for (subchap_num in 1:length(icd9_sub_chapters)) {
+    for (subchap_num in 1:length(icd::icd9_sub_chapters)) {
       if (majors[i] %ine% subchap_lookup[[subchap_num]]) {
-        out[i, "sub_chapter"] <- names(icd9_sub_chapters)[subchap_num]
+        out[i, "sub_chapter"] <- names(icd::icd9_sub_chapters)[subchap_num]
         break
       }
     }
   }
-  whch <- match(majors, icd9_majors, nomatch = NA)
-  out$major[] <- names(icd9_majors)[whch]
-  out$three_digit[] <- unlist(icd9_majors)[whch]
-  # out is based on unique majors of the input codes. Now merge with original inputs to give output
+  whch <- match(majors, icd::icd9_majors, nomatch = NA)
+  out$major[] <- names(icd::icd9_majors)[whch]
+  out$three_digit[] <- unlist(icd::icd9_majors)[whch]
+  # out is based on unique majors of the input codes. Now merge with original
+  # inputs to give output
   out <- merge(y = data.frame(three_digit = all_majors, stringsAsFactors = TRUE),
                x = out, by = "three_digit", sort = FALSE, all.x = TRUE)
   class(out[["three_digit"]]) <- c("icd9cm", "factor")
@@ -223,14 +223,14 @@ icd9_get_chapters <- function(x, short_code = guess_short(x), verbose = FALSE) {
 
 icd9_expand_chapter_majors <- function(chap) {
   expand_range_major.icd9(
-    icd9_chapters[[chap]]["start"],
-    icd9_chapters[[chap]]["end"],
+    icd::icd9_chapters[[chap]]["start"],
+    icd::icd9_chapters[[chap]]["end"],
     defined = FALSE)
 }
 
 icd9_expand_sub_chapter_majors <- function(subchap) {
   expand_range_major.icd9(
-    icd9_sub_chapters[[subchap]]["start"],
-    icd9_sub_chapters[[subchap]]["end"],
+    icd::icd9_sub_chapters[[subchap]]["start"],
+    icd::icd9_sub_chapters[[subchap]]["end"],
     defined = FALSE)
 }
