@@ -16,17 +16,8 @@
 # along with icd. If not, see <http:#www.gnu.org/licenses/>.
 
 # this is common code to all the tests, each of which runs test_check with a different filter:
-
 library("icd")
 library("testthat", warn.conflicts = FALSE, quietly = TRUE)
 library("magrittr", warn.conflicts = FALSE, quietly = TRUE)
-
-testthat::test_check("icd")
-
-# test deprecated functions:
-if (tolower(Sys.getenv("ICD_TEST_DEPRECATED")) %in% c("yes", "true"))
-  test_dir("../tests-deprecated")
-
-# test slow functions:
-if (tolower(Sys.getenv("ICD_TEST_BUILD_DATA")) %in% c("yes", "true"))
-  test_dir("../tests-build-data")
+if (!tolower(Sys.getenv("ICD_TEST_ALL")) %in% c("no", "false"))
+  testthat::test_check("icd")
