@@ -1,4 +1,4 @@
-# Copyright (C) 2014 - 2016  Jack O. Wasey
+# Copyright (C) 2014 - 2018  Jack O. Wasey
 #
 # This file is part of icd.
 #
@@ -15,25 +15,11 @@
 # You should have received a copy of the GNU General Public License
 # along with icd. If not, see <http:#www.gnu.org/licenses/>.
 
-# this is common code to all the tests, each of which runs test_check with a different filter:
-
 library("icd")
 library("testthat", warn.conflicts = FALSE, quietly = TRUE)
 library("magrittr", warn.conflicts = FALSE, quietly = TRUE)
-
-if (packageVersion("testthat") < package_version("0.11.0.9000")) {
-  message("testthat version is less than 0.11.0.9000, so not running Catch tests. Consider using:
-          devtools::install_github('hadley/testthat')")
-}
-
-options("icd.warn_deprecated" = FALSE)
-old_warn <- options(warn = -1)
-on.exit(options(old_warn))
-
-icd:::setup_test_check()
-icd:::show_test_options()
-if (icd:::doing_slow_tests()) {
-  icd:::my_test_check("deprecated", "Running deprecated tests")
-} else {
-  message("skipping deprecated tests because icd.do_slow_tests is FALSE")
-}
+library("checkmate", warn.conflicts = FALSE, quietly = TRUE)
+if (tolower(Sys.getenv("ICD_TEST_DEPRECATED")) %in% c("yes", "true"))
+  testthat::test_dir("tests-deprecated",
+                     env = icd:::test_env(),
+                     reporter = testthat::CheckReporter)
