@@ -24,36 +24,36 @@ test_that("setting conflicting icd data class gives error", {
 })
 
 test_that("well ordered class lists are created", {
-  expect_icd_classes_ordered(icd9(""))
-  expect_icd_classes_ordered(icd9cm(""))
-  expect_icd_classes_ordered(icd10(""))
-  expect_icd_classes_ordered(icd10cm(""))
+  expect_classes_ordered(icd9(""))
+  expect_classes_ordered(icd9cm(""))
+  expect_classes_ordered(icd10(""))
+  expect_classes_ordered(icd10cm(""))
 
-  expect_icd_classes_ordered(as.icd_short_diag(""))
-  expect_icd_classes_ordered(as.icd_decimal_diag(""))
-  expect_icd_classes_ordered(as.icd_decimal_diag(as.icd9("")))
+  expect_classes_ordered(as.short_diag(""))
+  expect_classes_ordered(as.decimal_diag(""))
+  expect_classes_ordered(as.decimal_diag(as.icd9("")))
 })
 
 test_that("well ordered class lists short/decimal ICD combos are created", {
-  expect_icd_classes_ordered(as.icd_short_diag(icd9("V102")))
-  expect_icd_classes_ordered(as.icd_decimal_diag(icd9cm("410.00")))
-  expect_icd_classes_ordered(as.icd_short_diag(icd10("A100")))
-  expect_icd_classes_ordered(as.icd_decimal_diag(icd10cm("B23.1")))
+  expect_classes_ordered(as.short_diag(icd9("V102")))
+  expect_classes_ordered(as.decimal_diag(icd9cm("410.00")))
+  expect_classes_ordered(as.short_diag(icd10("A100")))
+  expect_classes_ordered(as.decimal_diag(icd10cm("B23.1")))
 
-  expect_icd_classes_ordered(as.icd_decimal_diag(icd9("V10.2")))
-  expect_icd_classes_ordered(as.icd_short_diag(icd9cm("41000")))
-  expect_icd_classes_ordered(as.icd_decimal_diag(icd10("A10.0")))
-  expect_icd_classes_ordered(as.icd_short_diag(icd10cm("B231")))
+  expect_classes_ordered(as.decimal_diag(icd9("V10.2")))
+  expect_classes_ordered(as.short_diag(icd9cm("41000")))
+  expect_classes_ordered(as.decimal_diag(icd10("A10.0")))
+  expect_classes_ordered(as.short_diag(icd10cm("B231")))
 })
 
 test_that("is short or decimal code", {
-  # todo, somehow clarify that this is not the same is icd_is_valid...
-  expect_true(is.icd_short_diag(as.icd_short_diag("1234")))
-  expect_true(is.icd_decimal_diag(as.icd_decimal_diag("12.34")))
-  expect_true(is.icd_short_diag(as.icd_short_diag("1234")))
-  expect_true(is.icd_short_diag(as.icd_short_diag("1234")))
-  expect_true(is.icd_decimal_diag(as.icd_decimal_diag("12.34")))
-  expect_true(is.icd_decimal_diag(as.icd_decimal_diag("12.34")))
+  # todo, somehow clarify that this is not the same is is_valid...
+  expect_true(is.short_diag(as.short_diag("1234")))
+  expect_true(is.decimal_diag(as.decimal_diag("12.34")))
+  expect_true(is.short_diag(as.short_diag("1234")))
+  expect_true(is.short_diag(as.short_diag("1234")))
+  expect_true(is.decimal_diag(as.decimal_diag("12.34")))
+  expect_true(is.decimal_diag(as.decimal_diag("12.34")))
 })
 
 test_that("no warning or error for combining same types", {
@@ -75,8 +75,8 @@ test_that("attributes set and queried", {
   attr(x, "icd_short_diag") <- TRUE
   attr(y, "icd_short_diag") <- TRUE
   attr(z, "icd_short_diag") <- FALSE
-  expect_true(is.icd_short_diag(x))
-  expect_null(is.icd_short_diag(no_short_code))
+  expect_true(is.short_diag(x))
+  expect_null(is.short_diag(no_short_code))
 })
 
 test_that("ICD version supertype set", {
@@ -87,42 +87,42 @@ test_that("ICD version supertype set", {
 x <- icd9_map_quan_elix
 
 test_that("constructing a comorbidity map works", {
-  expect_equal(icd_comorbidity_map(x), x)
-  expect_equal(as.icd_comorbidity_map(x), x)
+  expect_equal(comorbidity_map(x), x)
+  expect_equal(as.comorbidity_map(x), x)
   expect_equivalent(as.list(x), x)
-  expect_equivalent(icd_comorbidity_map(as.list(x)), x)
+  expect_equivalent(comorbidity_map(as.list(x)), x)
 })
 
 test_that("constructing a comorbidity map with unnamed list, etc. fails", {
-  expect_error(as.icd_comorbidity_map(unname(unclass(x))))
+  expect_error(as.comorbidity_map(unname(unclass(x))))
   # and data frames should definitely fail
-  expect_error(as.icd_comorbidity_map(icd::vermont_dx))
-  expect_error(as.icd_comorbidity_map(icd::uranium_pathology))
+  expect_error(as.comorbidity_map(icd::vermont_dx))
+  expect_error(as.comorbidity_map(icd::uranium_pathology))
 })
 
 test_that("subsetting a comorbidity map gives the right class", {
 
-  wonky_map <- icd_comorbidity_map(list(a = as.icd9cm("100"), b = as.icd9cm("V22")))
+  wonky_map <- comorbidity_map(list(a = as.icd9cm("100"), b = as.icd9cm("V22")))
   attr(wonky_map$a, "icd_short_diag") <- TRUE
   attr(wonky_map$b, "icd_short_diag") <- TRUE
 
-  expect_is(wonky_map, "icd_comorbidity_map")
-  expect_null(is.icd_short_diag(wonky_map))
+  expect_is(wonky_map, "comorbidity_map")
+  expect_null(is.short_diag(wonky_map))
 
-  expect_true(!inherits(wonky_map[[1]], "icd_comorbidity_map"))
-  expect_true(is.icd_short_diag(wonky_map[[1]]))
+  expect_true(!inherits(wonky_map[[1]], "comorbidity_map"))
+  expect_true(is.short_diag(wonky_map[[1]]))
   expect_is(wonky_map[[1]], "icd9cm")
   expect_is(wonky_map[[1]], "icd9")
   expect_is(wonky_map[[1]], "character")
 
-  expect_true(!inherits(wonky_map$a, "icd_comorbidity_map"))
-  expect_true(is.icd_short_diag(wonky_map$a))
+  expect_true(!inherits(wonky_map$a, "comorbidity_map"))
+  expect_true(is.short_diag(wonky_map$a))
   expect_is(wonky_map$a, "icd9cm")
   expect_is(wonky_map$a, "icd9")
   expect_is(wonky_map$a, "character")
 
-  expect_true(!inherits(wonky_map[[2]], "icd_comorbidity_map"))
-  expect_true(is.icd_short_diag(wonky_map[[2]]))
+  expect_true(!inherits(wonky_map[[2]], "comorbidity_map"))
+  expect_true(is.short_diag(wonky_map[[2]]))
   expect_is(wonky_map[[2]], "icd9cm")
   expect_is(wonky_map[[2]], "icd9")
   expect_is(wonky_map[[2]], "character")
@@ -155,8 +155,8 @@ test_that("constructing wide or long format for non-data frame gives error", {
 })
 
 test_that("subsetting data frame works", {
-  expect_equal(unclass(icd::vermont_dx[1, 6]), as.icd_short_diag("27801"))
-  expect_equal(unclass(icd::vermont_dx[1, "DX1"]), as.icd_short_diag("27801"))
+  expect_equal(unclass(icd::vermont_dx[1, 6]), as.short_diag("27801"))
+  expect_equal(unclass(icd::vermont_dx[1, "DX1"]), as.short_diag("27801"))
   expect_is(icd::vermont_dx[1, "DX1"], c("icd9cm", "icd9", "character"))
   expect_equivalent(unclass(icd::vermont_dx[[1, 6]]), "27801")
   expect_is(icd::vermont_dx[[1, "DX1"]], c("icd9cm", "icd9", "character"))
@@ -179,35 +179,35 @@ test_that("data frame subsetting doesn't incorrectly set class on columns", {
 test_that("printing a comorbidity map works very simply", {
   expect_warning(
     capture.output(
-      print.icd_comorbidity_map(icd9_map_quan_elix)
+      print.comorbidity_map(icd9_map_quan_elix)
     ), regexp = NA)
 })
 
 test_that("is comorbidity map?", {
   icd9_map_ahrq %>%
     unclass %>%
-    icd_comorbidity_map -> x
-  expect_true(is.icd_comorbidity_map(icd9_map_ahrq))
-  expect_true(is.icd_comorbidity_map(x))
-  expect_is(icd9_map_ahrq, "icd_comorbidity_map")
-  expect_is(x, "icd_comorbidity_map")
+    comorbidity_map -> x
+  expect_true(is.comorbidity_map(icd9_map_ahrq))
+  expect_true(is.comorbidity_map(x))
+  expect_is(icd9_map_ahrq, "comorbidity_map")
+  expect_is(x, "comorbidity_map")
 })
 
 context("class conflicts")
 
 test_that("no conflict for standard classes", {
   expect_false(icd_classes_conflict(icd9("100.1")))
-  expect_false(icd_classes_conflict(icd9("100.1") %>% as.icd_decimal_diag))
-  expect_false(icd_classes_conflict(icd9("1001") %>% as.icd_short_diag))
+  expect_false(icd_classes_conflict(icd9("100.1") %>% as.decimal_diag))
+  expect_false(icd_classes_conflict(icd9("1001") %>% as.short_diag))
   expect_false(icd_classes_conflict(icd9cm("100.1")))
-  expect_false(icd_classes_conflict(icd9cm("100.1") %>% as.icd_decimal_diag))
-  expect_false(icd_classes_conflict(icd9cm("1001") %>% as.icd_short_diag))
+  expect_false(icd_classes_conflict(icd9cm("100.1") %>% as.decimal_diag))
+  expect_false(icd_classes_conflict(icd9cm("1001") %>% as.short_diag))
   expect_false(icd_classes_conflict(icd10("A00.0")))
-  expect_false(icd_classes_conflict(icd10("A00.0") %>% as.icd_decimal_diag))
-  expect_false(icd_classes_conflict(icd10("A000") %>% as.icd_short_diag))
+  expect_false(icd_classes_conflict(icd10("A00.0") %>% as.decimal_diag))
+  expect_false(icd_classes_conflict(icd10("A000") %>% as.short_diag))
   expect_false(icd_classes_conflict(icd10cm("A00.0")))
-  expect_false(icd_classes_conflict(icd10cm("A00.0") %>% as.icd_decimal_diag))
-  expect_false(icd_classes_conflict(icd10cm("A000") %>% as.icd_short_diag))
+  expect_false(icd_classes_conflict(icd10cm("A00.0") %>% as.decimal_diag))
+  expect_false(icd_classes_conflict(icd10cm("A000") %>% as.short_diag))
 })
 
 test_that("no conflict for built-in data", {
@@ -231,6 +231,19 @@ test_that("conflicting ICD type classes can be found", {
   expect_true(icd_classes_conflict(structure(list("V10", "A20"), class = c("icd9cm", "icd10", "list"))))
 })
 
+test_that("we can't set a data.frame to have a vector class", {
+  expect_error(as.icd9(data.frame()))
+  expect_error(as.icd9cm(data.frame()))
+  expect_error(as.icd10(data.frame()))
+  expect_error(as.icd10cm(data.frame()))
+
+  expect_error(as.icd9(vermont_dx))
+  expect_error(as.icd9cm(vermont_dx))
+
+  expect_error(as.icd10(uranium_pathology))
+  expect_error(as.icd10cm(uranium_pathology))
+})
+
 test_that("long vs wide data conflict identified", {
   v_bad <- vermont_dx
   class(v_bad) <- c(class(v_bad), "icd_long_data")
